@@ -178,7 +178,7 @@ service::instance::~instance()
 	service::locking.release();
 }
 
-void service::keyclone::enlist(keyclone *trunk)
+void service::keyclone::splice(keyclone *trunk)
 {
 	parent = trunk;
 	if(parent)
@@ -788,11 +788,8 @@ bool service::period(long slice)
 	FILE *fp = process::statfile();
 
 	if(fp) {
-		DateTime dt(periodic);
-		char buf[DateTime::sz_string];
-
-		dt.get(buf);
-		fprintf(fp, "%s %ld\n", buf, next - periodic);
+		DateTimeString dt(periodic);
+		fprintf(fp, "%s %ld\n", (const char *)dt, next - periodic);
 	}
 	periodic = next;
 	stats::period(fp);
